@@ -1,5 +1,5 @@
 package Mail::DMARC::Report::Store;
-our $VERSION = '1.20181001'; # VERSION
+our $VERSION = '1.20190308'; # VERSION
 use strict;
 use warnings;
 
@@ -22,6 +22,11 @@ sub retrieve {
     return $self->backend->retrieve(@_);
 }
 
+sub next_todo {
+    my $self = shift;
+    return $self->backend->next_todo(@_);
+}
+
 sub retrieve_todo {
     my $self = shift;
     return $self->backend->retrieve_todo(@_);
@@ -57,7 +62,7 @@ Mail::DMARC::Report::Store - persistent storage broker for reports
 
 =head1 VERSION
 
-version 1.20181001
+version 1.20190308
 
 =head1 SYNOPSIS
 
